#
# cheques-cpu-HD.R,  4 Feb 24
#
# Data from
# The Development of the ERMA Banking System: Lessons from History
# by AMY WEAVER FISHER and JAMES L. MCKENNEY
#
# and
# Evidence-Based Software Engineering
# by Derek Jones

library("colorspace")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


ch=read.csv("cheques-year.csv")

plot(ch, type="b", col="red",
	xlab="Year", ylab="Cheques (billions per year)")

dev.copy(dev=png, file="US-cheques-year.png")
dev.off()


bench=read.csv("comp-progress.csv.xz", as.is=TRUE)

bench=subset(bench, (technology == "Manual") |
			(technology == "Mechanical") |
			(technology == "Vacuum tube"))

tech_vec=unique(bench$technology)

pal_col=0
pal_col[tech_vec]=rainbow(length(tech_vec))

plot(0, type="n", log="y", cex=2.0,
        xlim=range(bench$Date), ylim=range(bench$total_cost_mill_ops),
        xlab="Date", ylab="Cost per million ops")

d_ply(bench, .(technology), function(df)
                        points(df$Date, df$total_cost_mill_ops, cex=1.6,
                                col=pal_col[df$technology]))

legend(x="bottomleft", legend=tech_vec, bty="n", fill=pal_col[tech_vec], cex=1.2)

dev.copy(dev=png, file="cost-million-ops_1960.png")
dev.off()


vac_tubes=subset(bench, (technology == "Vacuum tube"))

par(mar=c(4, 4, 1, 5))

plot(vac_tubes$Date, vac_tubes$total_cost_mill_ops, log="y", col="red", cex=1.5,
        xlim=c(1940, 1970),
        xlab="Date", ylab="Cost per million ops")


mag=read.csv("MemDiskPrice-mag.csv.xz", as.is=TRUE)
mag=subset(mag, date < 1970)

hd=subset(mag, Type != "floppy")

soft_scale=1

points(hd$date, soft_scale*hd$Cost.US./hd$Size.MBytes, col="blue", cex=1.5)

soft_pts=c(1000, 2000, 5000, 10000)
axis(side=4, at=soft_pts, labels=soft_pts*soft_scale, col="blue")
mtext("Dollars per MB", side=4, las=0, padj=4, col="blue")

legend(x="bottomright", legend=c("Cost per million ops", "Dollars per MB"), bty="n", fill=c("red", "blue"), cex=1.2)

dev.copy(dev=png, file="cost_million-vacops_dollars-MB.png")
dev.off()


